# import numpy
# import pandas

# Configuration variables

api_key = None
api_base = "https://petaldata.app/api"
cache_dir = None

# API Resources

from petaldata.resource import *
from petaldata.resource import abstract
from petaldata.resource import hubspot
from petaldata.resource import stripe
from petaldata.resource.stripe.reports import *


from petaldata.storage import *


import pandas as pd

class AbstractStorage(object):

  @classmethod
  def if_enabled(cls,base_pickle_filename):
    if (cls.enabled == True):
      return cls(base_pickle_filename)
    else:
      return None

  def __init__(self,base_pickle_filename):
    self.base_pickle_filename = base_pickle_filename
    assert(self.available()), "{} storage isn't available.".format(self.__class__)

  def available(self):
    pass

  def pickle_file_exists(self):
    pass

  @staticmethod
  def bytes_to_mb(bytes):
    return round(bytes/(1024*1024.0),2)



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="petaldata",
    version="0.0.3",
    author="Derek Haynes",
    author_email="derek@petaldata.com",
    description="Python bindings for the PetalData API",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/petaldata/petaldata-python",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=[
        'pandas',
        'numpy',
        'requests',
        'smart-open'
        'boto3'
    ],
)